# ifndef yyInquiry
# define yyInquiry

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Inquiry_Exit) ARGS ((void));

extern tTree TranslateInquiryCall ARGS ((tTree f));

extern void BeginInquiry ARGS ((void));
extern void CloseInquiry ARGS ((void));

# endif
